@@ -1,6 +1,6 @@
 package Pcore::App::MySQL;
 
-use Pcore qw[-class];
+use Pcore -class;
 
 extends qw[Pcore::App::Alien];
 
@@ -36,12 +36,12 @@ around _build_cfg => sub ( $orig, $self ) {
                     character_set_server          => 'utf8',
                     collation_server              => 'utf8_general_ci',
                     log_output                    => 'FILE',
-                    log_error                     => $PROC->{LOG_DIR} . $self->name . q[-mysql-error.log],
+                    log_error                     => $ENV->{LOG_DIR} . $self->name . q[-mysql-error.log],
                     log_warnings                  => 1,
                     general_log                   => 0,
-                    general_log_file              => $PROC->{LOG_DIR} . $self->name . q[-mysql-general.log],
+                    general_log_file              => $ENV->{LOG_DIR} . $self->name . q[-mysql-general.log],
                     slow_query_log                => 1,
-                    slow_query_log_file           => $PROC->{LOG_DIR} . $self->name . q[-mysql-slow-queries.log],
+                    slow_query_log_file           => $ENV->{LOG_DIR} . $self->name . q[-mysql-slow-queries.log],
                     long_query_time               => 2,
                     log_short_format              => 1,
                     log_queries_not_using_indexes => 1,
